@@ -4,7 +4,7 @@ use salvo::extra::ws::WsHandler;
 use salvo::prelude::*;
 
 #[fn_handler]
-async fn connect(req: &mut Request, res: &mut Response) -> Result<(), HttpError> {
+async fn connect(req: &mut Request, res: &mut Response) -> Result<(), StatusError> {
     let fut = WsHandler::new().handle(req, res)?;
     let fut = async move {
         if let Some(ws) = fut.await {
@@ -25,6 +25,6 @@ async fn connect(req: &mut Request, res: &mut Response) -> Result<(), HttpError>
 async fn main() {
     tracing_subscriber::fmt().init();
     let router = Router::new().handle(connect);
-    tracing::info!("Listening on http://127.0.0.1:7878");
-    Server::new(TcpListener::bind("127.0.0.1:7878")).serve(router).await;
+    tracing::info!("Listening on http://0.0.0.0:7878");
+    Server::new(TcpListener::bind("0.0.0.0:7878")).serve(router).await;
 }
